library flutter_notification_center;

class FlutterNotificationCenter {
  final _observers = <String, List<Function>>{};

  static final FlutterNotificationCenter _instance = FlutterNotificationCenter.internal();

  factory FlutterNotificationCenter() => _instance;

  FlutterNotificationCenter.internal();

  void addObserver(String notificationId, Function callback) {
    if (!_observers.containsKey(notificationId)) {
      _observers[notificationId] = [];
    }
    _observers[notificationId]?.add(callback);
  }

  void removeObserver(String notificationId, {Function? callback}) {
    if (callback != null) {
      if (_observers.containsKey(notificationId)) {
        _observers[notificationId]!.remove(callback);
      }
    } else {
      _observers.remove(notificationId);
    }
  }

  void post(String notificationId, {dynamic data}) {
    if (_observers.containsKey(notificationId)) {
      final observer = _observers[notificationId]!;
      if (data != null) {
        for (var callback in observer) {
          callback(data);
        }
      } else {
        for (var callback in observer) {
          callback();
        }
      }
    }
  }
}
